@@ -119,7 +119,7 @@ class App(BoxContainer):
 
         config = self.create_config()
         self.__reset_data()
-        config = config.json()
+        config = json_dumps_fn(config.dict())
 
         with open(get_project_root() / 'template/index.html',
                   mode='r',
