@@ -24,7 +24,7 @@ class MethodPropInfo(AbsPropInfo):
 
     def _ex_gen_expr(self):
         args = ','.join(value2code(v) for v in self.args)
-        return f'.{self.name}({args})'
+        return f'?.{self.name}({args})'
 
 
 class LambdaMethodPropInfo(AbsPropInfo):
